## gitmodules

[![Version](https://img.shields.io/badge/version-2021.5-12-blue)](https://github.com/maite828/gitmodules.git)
[![Version](https://img.shields.io/badge/module_A-2.7.0-yellow)](https://github.com/maite828/module_A.git)
[![Version](https://img.shields.io/badge/module_B-1.6.0-yellow)](https://github.com/maite828/module_B.git)

# CONTAINER MODULE
This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.